.. _api_geometry_cube:

.. currentmodule:: microstructpy.geometry

microstructpy.geometry.Cube
===========================

.. autoclass:: Cube
    :members:
    :undoc-members:
    :inherited-members:
